package com.company.example.web.sample;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.annotation.Action;
import org.jdesigner.platform.web.annotation.Forward;
import org.jdesigner.platform.web.annotation.View;
import org.jdesigner.platform.web.annotation.Web;
import org.jdesigner.platform.web.fileupload.MultiFileUpload;
import org.jdesigner.platform.web.fileupload.SingleFileUpload;
import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.grid.Grid;
import org.jdesigner.platform.web.json.JSONResult;
import org.jdesigner.platform.web.table.Table;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.FileUploadService;

import com.company.example.service.sample.SampleService;
import com.company.example.web.BaseActionBean;

/**
 * CRUDBean
 * 
 * @author leesangboo
 * 
 */
@Web(namespace = "sample_crud_bean")
public class CRUDBean extends BaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(CRUDBean.class);

	private Form form;
	private Form search;
	private Grid grid;
	private Table table;
	private JSONResult json;
	private SingleFileUpload single_fileupload;
	private MultiFileUpload multi_fileupload;

	private FileUploadService fileupload_service;
	private SampleService sample_service;

	public CRUDBean() {
		init();//
	}

	private void init() {
		//
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		//
		search = new Form();
		form = new Form();
		table = new Table();
		grid = new Grid();
		json = new JSONResult();
		single_fileupload = new SingleFileUpload();
		multi_fileupload = new MultiFileUpload();
		//
		fileupload_service = CommonServiceFactory.getFileUploadService();
		sample_service = new SampleService();
	}

	@Override
	public void reset() {
		//
	}

	@Action(path = "/sample/crud/index")
	@Forward(name = View.SUCCESS, layout = ".main.layout", title = SampleTitles.CRUD_INDEX, content = "/sample/crud/index.jsp")
	public String index() throws Exception {
		return View.SUCCESS;
	}

	@Action(path = "/sample/crud/grid")
	public String grid() throws Exception {
		grid = new Grid(sample_service.selectPage(search, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return View.GRID;
	}

	@Action(path = "/sample/crud/add")
	@Forward(name = View.SUCCESS, layout = ".main.layout", title = SampleTitles.CRUD_ADD, content = "/sample/crud/form.jsp")
	public String add() throws Exception {
		form.setMode(FormMode.INSERT);
		return View.SUCCESS;
	}

	@Action(path = "/sample/crud/edit")
	@Forward(name = View.SUCCESS, layout = ".main.layout", title = SampleTitles.CRUD_EDIT, content = "/sample/crud/form.jsp")
	public String edit() throws Exception {
		form.setMode(FormMode.UPDATE);
		form.putAll(sample_service.selectMap(form));
		return View.SUCCESS;
	}

	@Action(path = "/sample/crud/insert")
	@Forward(name = View.SUCCESS, layout = ".main.layout", title = SampleTitles.CRUD_INDEX, content = "/sample/crud/index.jsp")
	public String insert() throws Exception {
		//
		fileupload_service.saveSingleFile(single_fileupload, "c:/temp/");
		fileupload_service.saveMultiFile(multi_fileupload, "c:/temp/");
		//
		sample_service.insert(form);
		super.setServerMessage("common.insert.success");
		init();
		return View.SUCCESS;
	}

	@Action(path = "/sample/crud/update")
	@Forward(name = View.SUCCESS, layout = ".main.layout", title = SampleTitles.CRUD_INDEX, content = "/sample/crud/index.jsp")
	public String update() throws Exception {
		sample_service.update(form);
		super.setServerMessage("common.update.success");
		init();
		return View.SUCCESS;
	}

	@Action(path = "/sample/crud/delete")
	@Forward(name = View.SUCCESS, layout = ".main.layout", title = SampleTitles.CRUD_INDEX, content = "/sample/crud/index.jsp")
	public String delete() throws Exception {
		sample_service.delete(form);
		super.setServerMessage("common.delete.success");
		init();
		return View.SUCCESS;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

	public Table getTable() {
		return table;
	}

	public void setTable(Table table) {
		this.table = table;
	}

	public JSONResult getJson() {
		return json;
	}

	public void setJson(JSONResult json) {
		this.json = json;
	}

	public SingleFileUpload getSingle_fileupload() {
		return single_fileupload;
	}

	public void setSingle_fileupload(SingleFileUpload singleFileupload) {
		single_fileupload = singleFileupload;
	}

	public MultiFileUpload getMulti_fileupload() {
		return multi_fileupload;
	}

	public void setMulti_fileupload(MultiFileUpload multiFileupload) {
		multi_fileupload = multiFileupload;
	}

}
