/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.domain;

import java.util.ArrayList;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * <B>사용자 로그인 정보</B>
 * 
 * @author leesangboo
 * 
 */
public class UserLogin implements Comparable, java.io.Serializable {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(UserLogin.class);

	private String ip;

	private String username;

	private String password;

	private ArrayList roles;

	private int hashCode = Integer.MIN_VALUE;

	public UserLogin() {
		//
	}

	public UserLogin(String ip, String username, String password, ArrayList roles) {
		super();
		this.ip = ip;
		this.username = username;
		this.password = password;
		this.roles = roles;
	}

	public UserLogin(String ip, String username) {
		this.ip = ip;
		this.username = username;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getUsername() {
		return this.username;
	}

	public void setUsername(String username) {
		this.username = username;
	}

	public void setRoles(ArrayList roles) {
		this.roles = roles;
	}

	public ArrayList getRoles() {
		return this.roles;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public void addRole(String role) {
		if (this.roles == null) {
			this.roles = new ArrayList();
		}

		if (this.hasRole(role)) {
			throw new IllegalArgumentException("User has already the role" + role);
		}

		this.roles.add(role);
	}

	public String getPassword() {
		return this.password;
	}

	public boolean hasRole(String role) {
		if (roles == null) {
			return false;
		}
		return roles.contains(role);
	}

	public String getFirstRole() {
		if (roles == null || roles.size() > 0) {
			log.warn("First role is null or size == 0. return null.");
			return null;
		}
		return (String) roles.get(0);
	}

	public boolean equals(Object obj) {
		if (null == obj) {
			return false;
		}
		if (!(obj instanceof UserLogin)) {
			return false;
		} else {
			UserLogin x = (UserLogin) obj;
			if (null == this.getUsername() || null == x.getUsername()) {
				return false;
			} else {
				return (this.getUsername().equals(x.getUsername()));
			}
		}
	}

	public int hashCode() {
		if (Integer.MIN_VALUE == this.hashCode) {
			if (null == this.getUsername()) {
				return super.hashCode();
			} else {
				String hashStr = this.getClass().getName() + ":" + this.getUsername().hashCode();
				this.hashCode = hashStr.hashCode();
			}
		}
		return this.hashCode;
	}

	public int compareTo(Object obj) {
		if (obj.hashCode() > hashCode()) {
			return 1;
		} else if (obj.hashCode() < hashCode()) {
			return -1;
		} else {
			return 0;
		}
	}

	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}

}
