/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.application.template.logging.oracle;

import org.apache.log4j.spi.LocationInfo;
import org.apache.log4j.spi.LoggingEvent;
import org.apache.log4j.spi.ThrowableInformation;

import org.jdesigner.platform.util.DateUtils;

import org.jdesigner.application.template.logging.IDGenerator;
import org.jdesigner.application.template.logging.MDCKeys;

/**
 * OracleSQLHandler
 * 
 * @author leesangboo
 * 
 */
public class OracleSQLHandler {

	private final int MAX_LENGTH_MESSAGE = 3000;

	/**
	 * return database SQL statement to log logging event
	 * 
	 * @param event
	 *            the event
	 * @return SQL insert statement
	 * @throws Exception
	 *             if any error occurs
	 * @see org.apache.log4j.jdbcplus.JDBCSqlHandler#getStatement(LoggingEvent)
	 */
	public String getStatement(String table, LoggingEvent event) throws Exception {

		//
		LocationInfo locinfo = event.getLocationInformation();
		ThrowableInformation throwableinfo = event.getThrowableInformation();
		StringBuffer throwableStringBuffer = new StringBuffer();
		String locinfoString = "'', '', '', ''";
		//
		if (locinfo != null) {
			locinfoString = "'" + locinfo.getClassName() + "', '" + locinfo.getMethodName() + "', '" + locinfo.getFileName() + "', '" + locinfo.getLineNumber() + "'";
		}
		if (throwableinfo != null) {
			String[] lines = throwableinfo.getThrowableStrRep();
			for (int index = 0; index < lines.length; index++) {
				throwableStringBuffer = throwableStringBuffer.append(lines[index] + "\r\n");
			}
		}

		long logNumber = IDGenerator.generateLogNumber();

		/* Log4j 1.3 + new Date(event.getTimeStamp()) */
		/* Log4j 1.2.8 + new Date(event.timeStamp) */

		StringBuffer statementbuffer = new StringBuffer(2048);
		statementbuffer
				.append("INSERT INTO "
						+ table
						+ " (LOG_DATE, LOG_NUMBER, LOGGER, PRIORITY, LOC_CLASSNAME, LOC_METHODNAME, LOC_FILENAME, LOC_LINENUMBER, LOG_MESSAGE, THROWABLE, INSERT_DATE, JSESSION_ID, PROCESS_ID, REMORTE_HOST, REMORTE_ADDRESS, REQUEST_URI, REQUEST_QUERY, USERNAME) VALUES ( ");
		statementbuffer.append("  TO_DATE('" + DateUtils.timestampToISO(new java.sql.Timestamp(event.timeStamp), true) + "', 'YYYY-MM-DD HH24:MI:SS')");
		statementbuffer.append(", '" + logNumber + "'");
		statementbuffer.append(", '" + event.getLoggerName() + "'");
		statementbuffer.append(", '" + event.getLevel().toString() + "'");
		statementbuffer.append(", " + locinfoString + "");
		statementbuffer.append(", '" + this.replaceProblematicChars(event.getMessage() == null ? "null" : event.getMessage().toString()) + "'");
		statementbuffer.append(", '" + this.replaceProblematicChars(throwableStringBuffer.toString()) + "'");
		statementbuffer.append(", SYSDATE ");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.JSESSION_ID_KEY) + "'");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.PROCESS_ID_KEY) + "'");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.REMORTE_HOST_KEY) + "'");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.REMORTE_ADDRESS_KEY) + "'");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.REQUEST_URI_KEY) + "'");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.REQUEST_QUERY_KEY) + "'");
		statementbuffer.append(", '" + event.getMDC(MDCKeys.USERNAME_KEY) + "'");
		statementbuffer.append(")");
		return statementbuffer.toString();
	}

	/**
	 * 
	 * @param aString
	 * @return
	 */
	protected String replaceProblematicChars(String aString) {
		String result = new String(aString);
		// use replace function
		result = result.replaceAll("'", "''");
		if (result.length() > MAX_LENGTH_MESSAGE) {
			result = result.substring(0, MAX_LENGTH_MESSAGE);
		}
		return result;
	}

}