/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.impl;

import javax.transaction.UserTransaction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.transaction.JTATransactionManager;

import org.jdesigner.application.template.service.CommonServiceException;
import org.jdesigner.application.template.service.CommonServiceProperties;
import org.jdesigner.application.template.service.TransactionService;

/**
 * TransactionServiceImpl
 * 
 * @author SangBoo Lee
 * @date 2009. 12. 18.
 * @since 1.0
 * 
 */
public class TransactionServiceImpl implements TransactionService {

	private static final Log log = LogFactory.getLog(TransactionServiceImpl.class);

	private String JTA_JNDI_KEY = "service.transaction.jta.jndi";

	private JTATransactionManager manager = new JTATransactionManager();

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.TransactionService#start()
	 */
	public UserTransaction start() throws CommonServiceException {
		try {
			log.info("Transaction service starting...");
			String jndiName = CommonServiceProperties.getString(JTA_JNDI_KEY);
			return manager.begin(jndiName);
		} catch (Exception ex) {
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.TransactionService#commit (javax.transaction.UserTransaction)
	 */
	public void commit(UserTransaction userTransaction) throws CommonServiceException {
		try {
			manager.commit(userTransaction);
			log.info("Transaction service commited.");
		} catch (Exception ex) {
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.TransactionService#rollback (javax.transaction.UserTransaction)
	 */
	public void rollback(UserTransaction userTransaction) throws CommonServiceException {
		manager.rollback(userTransaction);
		log.info("Transaction service rollbacked.");
	}

}
