/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.lifecycle;

import java.util.List;
import java.util.Timer;

import javax.servlet.ServletContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.scheduler.SchedulerFactory;
import org.jdesigner.platform.scheduler.task.SchedulerTask;
import org.jdesigner.platform.scheduler.task.SchedulerTaskInfo;

import org.jdesigner.application.template.service.config.SchedulerConfigurationLoader;

/**
 * SchedulerLifecycle
 * 
 * @author SangBoo Lee
 * @date 2010. 3. 1.
 * @since 1.0
 * 
 */
public class SchedulerLifecycle {

	private static final Log log = LogFactory.getLog(CacheLifecycle.class);

	private static class SchedulerLifecycleHolder {
		static SchedulerLifecycle instance = new SchedulerLifecycle();
	}

	public static SchedulerLifecycle getInstance() {
		return SchedulerLifecycleHolder.instance;
	}

	/**
	 * 스케줄러를 시작한다.
	 * 
	 * @param context
	 * @param config
	 */
	public void start(ServletContext context, String config) {

		try {

			log.info("Scheduler staring...");

			SchedulerConfigurationLoader loader = SchedulerConfigurationLoader.getInstance();
			List taskList = loader.load(config);

			SchedulerFactory sechudlerFactory = SchedulerFactory.getInstance();

			// Load and run timers
			int totalTaskSize = 0;
			for (int i = 0; taskList != null && i < taskList.size(); i++) {
				SchedulerTaskInfo taskInfo = (SchedulerTaskInfo) taskList.get(i);
				SchedulerTask task = sechudlerFactory.createSchedulerTask(context, taskInfo);
				sechudlerFactory.launchTimer(task, taskInfo);
				totalTaskSize++;
			}
			log.info("Running total scheduler task size=[" + totalTaskSize + "]");

			log.info("Scheduler has been started.");

		} catch (Exception e) {
			String msg = "Scheduler start failed : " + e.getMessage();
			log.error(msg, e);
			throw new RuntimeException(msg);
		}
	}

	/**
	 * 스케쥴러를 정지한다.
	 * 
	 * @param context
	 */
	public void stop() {
		SchedulerFactory sechudlerFactory = SchedulerFactory.getInstance();
		List timerList = sechudlerFactory.getTimerList();
		if (timerList != null && timerList.size() > 0) {
			for (int i = 0; i < timerList.size(); i++) {
				Timer timer = (Timer) timerList.get(i);
				timer.cancel();
			}
		}
		log.info("Scheduler has been stopped.");
	}

}
