/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.provider;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPFile;

import org.jdesigner.application.template.service.CommonServiceException;

/**
 * FTPImpl
 * 
 * @author SangBoo Lee
 * @date 2009. 11. 16.
 * @since 1.0
 * 
 */
public class CommonsFTPClientImpl implements FTP {

	private static final Log log = LogFactory.getLog(CommonsFTPClientImpl.class);

	/**
	 * Delegation class
	 */
	protected FTPClient delegate;

	public CommonsFTPClientImpl() {
		delegate = new FTPClient();
	}

	public boolean isConnected() {
		return delegate.isConnected();
	}

	public void setControlEncoding(String encoding) throws CommonServiceException {
		delegate.setControlEncoding(encoding);
	}

	public boolean setFileType(int arg0) throws CommonServiceException {
		try {
			return delegate.setFileType(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean changeWorkingDirectory(String arg0) throws CommonServiceException {
		try {
			return delegate.changeWorkingDirectory(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean deleteFile(String arg0) throws CommonServiceException {
		try {
			return delegate.deleteFile(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public void disconnect() throws CommonServiceException {
		try {
			delegate.disconnect();
		} catch (IOException ex) {
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public FTPFile[] listFiles() throws CommonServiceException {
		try {
			return delegate.listFiles();
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public String[] listNames() throws CommonServiceException {
		try {
			return delegate.listNames();
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public String[] listNames(String arg0) throws CommonServiceException {
		try {
			return delegate.listNames(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean login(String username, String password, String host) throws CommonServiceException {
		try {
			boolean isLoged = false;

			delegate.connect(host);

			if (delegate.isConnected()) {
				isLoged = delegate.login(username, password);
			}

			log.info("FTP Logined : HOST=[" + host + "]");

			return isLoged;
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean logout() throws CommonServiceException {
		try {
			return delegate.logout();
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean makeDirectory(String arg0) throws CommonServiceException {
		try {
			return delegate.makeDirectory(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean retrieveFile(String arg0, OutputStream arg1) throws CommonServiceException {
		try {
			return delegate.retrieveFile(arg0, arg1);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public InputStream retrieveFileStream(String arg0) throws CommonServiceException {
		try {
			return delegate.retrieveFileStream(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean storeFile(String arg0, InputStream arg1) throws CommonServiceException {
		try {
			return delegate.storeFile(arg0, arg1);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public boolean storeUniqueFile(String arg0, InputStream arg1) throws CommonServiceException {
		try {
			return delegate.storeUniqueFile(arg0, arg1);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public int mkd(String pathname) throws CommonServiceException {
		try {
			return delegate.mkd(pathname);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public int pasv() throws CommonServiceException {
		try {
			return delegate.pasv();
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.opentrends.openframe.services.ftp.FtpClientIF#sendCommand(java.lang .String)
	 */
	public int sendCommand(String arg0) throws CommonServiceException {
		try {
			return delegate.sendCommand(arg0);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public int sendCommand(String arg0, String arg1) throws CommonServiceException {
		try {
			return delegate.sendCommand(arg0, arg1);
		} catch (IOException ex) {
			if (delegate.isConnected()) {
				disconnect();
			}
			throw new CommonServiceException(ex.getMessage(), ex);
		}
	}

	public Object clone() throws CloneNotSupportedException {
		FTP result = new CommonsFTPClientImpl();
		return result;
	}

}