/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.cache.impl;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Properties;

import org.jdesigner.platform.cache.Cache;
import org.jdesigner.platform.cache.CacheException;

/**
 * LRUCache
 * 
 * @author leesangboo
 * 
 */
public class LRUCache implements Cache {

	private static final long serialVersionUID = 1L;

	private int MAX_ENTRIES = 100;

	public static final String CONFIG_MAX_ENTRIES_KEY = "max-entries";

	public LRUCache() {
		//
	}

	public LRUCache(Properties configuration) {
		if (configuration != null) {
			int maxEntries = Integer.parseInt(configuration.getProperty(CONFIG_MAX_ENTRIES_KEY));
			MAX_ENTRIES = maxEntries;
		}
	}

	private Map cache = new LinkedHashMap(MAX_ENTRIES + 1, .75F, true) {
		private static final long serialVersionUID = 1858974880118887288L;

		public boolean removeEldestEntry(Map.Entry eldest) {
			return size() > MAX_ENTRIES;
		}
	};

	public Object get(String key) throws CacheException {
		return cache.get(key);
	}

	public boolean hasValue(String key) throws CacheException {
		Object o = cache.get(key);
		if (o == null && !cache.containsKey(key)) {
			return false;
		} else {
			return true;
		}
	}

	public void remove(String key) throws CacheException {
		cache.remove(key);
	}

	public void put(String key, Object value) throws CacheException {
		cache.put(key, value);
	}

	public void flush() throws CacheException {
		cache.clear();
	}

	public Map toMap() throws CacheException {
		return cache;
	}

}
