/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.data;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

/**
 * <B>Tree</B>
 * 
 * <pre> EX) List list = new ArrayList();
 * 
 * list.add(new TreeNode(15, 11, new HashMap())); list.add(new TreeNode(15, 11, new HashMap()));
 * 
 * Tree tree = new Tree(); tree.addAll(list); </pre>
 * 
 * @author SangBoo Lee
 * @since 1.0
 * 
 */
public class Tree {

	public static final String ROOT = "ROOT";

	private TreeNode root;

	public Tree() {
		root = new TreeNode(ROOT, null, new HashMap());
	}

	public void add(TreeNode item) {
		root.add(item);
	}

	public void addAll(List list) {
		Iterator iter = list.iterator();
		while (iter.hasNext()) {
			add((TreeNode) iter.next());
		}
	}

	public TreeNode getRoot() {
		return root;
	}

	public void setRoot(TreeNode root) {
		this.root = root;
	}

	public String toString() {
		return toString(root);
	}

	public String iterate(TreeIterateHandler handler) {
		return iterate(root, handler);
	}

	public String iterate(TreeNode node, TreeIterateHandler handler) {
		StringBuffer sb = new StringBuffer();
		Iterator iter = node.getNodes().iterator();
		while (iter.hasNext()) {
			sb.append(iterate((TreeNode) iter.next(), handler));
		}
		sb.append(handler.process(node));
		return sb.toString();
	}

	public String toString(TreeNode node) {
		StringBuffer sb = new StringBuffer();
		Iterator iter = node.getNodes().iterator();
		while (iter.hasNext()) {
			sb.append(toString((TreeNode) iter.next()));
		}
		String plus = decorationPlus(node);
		return "\n" + plus + node.getCode() + sb.toString();
	}

	private static String decorationPlus(TreeNode node) {
		StringBuffer plus = new StringBuffer();
		for (int i = 0; i < node.getDepth(); i++) {
			plus.append("  ");
		}
		plus.append("+");
		return plus.toString();
	}
}
