/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Persistence Manager
 * 
 * @author leesangboo
 * 
 */
public class PersistenceManager {

	private static final Log log = LogFactory.getLog(PersistenceManager.class);

	private static final String DEFAULT_PERSISTENCE_ID = "org.jdesigner.platform.db.DEFAULT_PERSISTENCE";

	/**
	 * 기본 Persistence 를 반환한다.
	 * 
	 * @return
	 */
	public static Persistence getPersistence() {
		return getPersistence(DEFAULT_PERSISTENCE_ID);
	}

	/**
	 * Persistence 를 반환한다.
	 * 
	 * @param id
	 * @return
	 */
	public static Persistence getPersistence(String id) {
		Persistence persistence = PersistenceContext.getPersistence(id);
		if (persistence == null) {
			log.debug("Create new persistence : ID=[" + id + "]");
			persistence = PersistenceFactory.createPersistence(id);
			PersistenceContext.addPersistence(id, persistence);
		}
		return persistence;
	}

	/**
	 * Persistence 를 반환한다.
	 * 
	 * @param id
	 * @param dataSourceJNDIName
	 * @param transactionType
	 * @return
	 */
	public static Persistence getPersistence(String id, String dataSourceJNDIName, int transactionType) {
		Persistence persistence = PersistenceContext.getPersistence(id);
		if (persistence == null) {
			log.debug("Create new persistence : ID=[" + id + "]");
			persistence = PersistenceFactory.createPersistence(id, dataSourceJNDIName, transactionType);
			PersistenceContext.addPersistence(id, persistence);
		}
		return persistence;
	}

}
