/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.handler;

import org.jdesigner.platform.context.ApplicationConfig;
import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.db.vender.DatabaseName;

/**
 * ColumnTypeResultObjectHandlerFactory
 * 
 * @author leesangboo
 * 
 */
public class ColumnTypeResultObjectHandlerFactory {

	private static final String DATABASE_NAME_KEY = "platform.db.database";

	/**
	 * ColumnTypeResultObjectHandler를 반환한다.
	 * 
	 * @return
	 */
	public static ColumnTypeResultObjectHandler getColumnTypeResultObjectHandler() {
		ApplicationContextFactory appFactory = ApplicationContextFactory.getInstance();
		ApplicationConfig appConfig = appFactory.getApplicationContext().getApplicationConfig();
		String dbName = appConfig.getProperty(DATABASE_NAME_KEY);
		//
		if (dbName.startsWith(DatabaseName.ORACLE)) {
			return new OracleColumnTypeResultObjectHandler();
		} else {
			return new PropertiesColumnTypeResultObjectHandler();
		}
	}

}
