/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.handler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.Calendar;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * OracleColumnTypeResultObjectHandler
 * 
 * @author leesangboo
 * 
 */
public class OracleColumnTypeResultObjectHandler implements ColumnTypeResultObjectHandler {

	private static final Log log = LogFactory.getLog(OracleColumnTypeResultObjectHandler.class);

	private static final String NUMBER = "NUMBER";

	private static final String VARCHAR2 = "VARCHAR2";

	private static final String CHAR = "CHAR";

	private static final String DATE = "DATE";

	private static final String LONG = "LONG";

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.handler.ColumnTypeResultObjectHandler#getObject (java.sql.ResultSet, java.lang.String, java.lang.String, int)
	 */
	public Object getObject(ResultSet rs, String columnType, String columnName, int columnIndex) throws SQLException {
		try {
			if (columnType.equals(CHAR) || columnType.equals(VARCHAR2) || columnType.equals(LONG)) {
				return rs.getString(columnIndex);
			} else if (columnType.equals(NUMBER)) {
				return rs.getBigDecimal(columnIndex);
			} else if (columnType.equals(DATE)) {
				Timestamp timestampValue = rs.getTimestamp(columnIndex);
				if (timestampValue != null) {
					java.sql.Date dateValue = new java.sql.Date(timestampValue.getTime());
					java.util.Calendar cal = java.util.Calendar.getInstance();
					cal.setTime(dateValue);
					if (cal.get(Calendar.HOUR) == 0 && cal.get(Calendar.MINUTE) == 0 && cal.get(Calendar.SECOND) == 0) {
						return dateValue;
					} else {
						return timestampValue;
					}
				} else {
					return null;
				}
			} else {
				if (log.isDebugEnabled()) {
					log.debug("Default rs.getObject(columnIndex) invoke.");
				}
				return rs.getObject(columnIndex);
			}
		} catch (Exception ex) {
			throw new SQLException("OracleColumnTypeResultObjectHandler Error : " + ex.getMessage());
		}
	}

}
