/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.lob;

import org.jdesigner.platform.context.ApplicationConfig;
import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.db.vender.DatabaseName;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * LOBHandlerFactory
 * 
 * @author leesangboo
 * 
 */
public class LOBHandlerFactory {

	private static final String DATABASE_NAME_KEY = "platform.db.database";

	private static class LOBHandlerFactoryHolder {
		static LOBHandlerFactory instance = new LOBHandlerFactory();
	}

	public static LOBHandlerFactory getInstance() {
		return LOBHandlerFactoryHolder.instance;
	}

	private LOBHandler lobHandler;

	/**
	 * LOBHandler를 반환한다.
	 * 
	 * @return
	 * @throws DatabaseException
	 */
	public LOBHandler getLOBHandler() throws DatabaseException {
		if (lobHandler == null) {
			ApplicationContextFactory appFactory = ApplicationContextFactory.getInstance();
			ApplicationConfig appConfig = appFactory.getApplicationContext().getApplicationConfig();
			String dbName = appConfig.getProperty(DATABASE_NAME_KEY);

			//
			if (dbName.startsWith(DatabaseName.ORACLE)) {
				lobHandler = new OracleLOBHandler();
			} else {
				throw new DatabaseException("Unsupport LOB handler this database type : " + dbName);
			}
			return lobHandler;
		} else {
			return lobHandler;
		}

	}

}
