/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.parameter;

import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Map;

import org.jdesigner.platform.db.domain.BLOBByteArrayType;
import org.jdesigner.platform.db.domain.BLOBFileType;
import org.jdesigner.platform.db.domain.CLOBStringType;
import org.jdesigner.platform.db.lob.LOBHandler;
import org.jdesigner.platform.db.lob.LOBHandlerFactory;
import org.jdesigner.platform.db.parser.QueryParsingException;
import org.jdesigner.platform.util.FileUtils;

/**
 * OracleBindParamHandler
 * 
 * @author leesangboo
 * 
 */
public class OracleParameterBinderHandler implements ParameterBinder {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.bind.BindParamHandler#bind(java.sql.Connection , java.lang.Object[])
	 */
	public Object[] bind(Connection conn, Object[] params) throws SQLException {
		Object[] bindParam = null;
		try {
			if (params != null && params.length > 0) {
				bindParam = new Object[params.length];
				for (int i = 0; i < params.length; i++) {
					Object param = params[i];
					if (param != null) {
						bindParam[i] = convertObject(conn, param);
					} else {
						bindParam[i] = null;
					}
				}
			} else {
				return null;
			}
			return bindParam;
		} catch (Exception ex) {
			String msg = "OracleParameterBinder exception : " + ex.getMessage();
			throw new SQLException(msg);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.bind.BindParamHandler#bind(java.sql.Connection , java.util.Map)
	 */
	public Map bind(Connection conn, Map params) throws SQLException {
		try {
			if (params != null && !params.isEmpty()) {
				Object[] keys = params.keySet().toArray();
				for (int i = 0; i < keys.length; i++) {

					if (params.containsKey(keys[i]) && params.get(keys[i]) != null && params.get(keys[i]).getClass().isArray()) {
						// throw new
						// java.lang.IllegalArgumentException("Map must not be in the value array.");
					} else {
						Object param = params.get(keys[i]);
						if (param != null) {
							if (param != null) {
								params.put(keys[i], convertObject(conn, param));
							} else {
								params.put(keys[i], null);
							}
						} else {
							params.put(keys[i], null);
						}
					}
				}
			} else {
				return null;
			}

			return params;

		} catch (Exception ex) {
			String msg = "OracleParameterBinder exception : " + ex.getMessage();
			throw new SQLException(msg);
		}

	}

	/**
	 * 파라메터를 병합할 오브젝트로 변환한다.
	 * 
	 * @param conn
	 * @param param
	 * @return
	 * @throws QueryParsingException
	 * @throws IOException
	 */
	private Object convertObject(Connection conn, Object param) throws SQLException, IOException {
		Class typeClass = param.getClass();
		// java.util.Date
		if (typeClass.equals(java.util.Date.class)) {
			return new java.sql.Date(((java.util.Date) param).getTime());
			// CLOBStringType
		} else if (typeClass.equals(CLOBStringType.class)) {
			LOBHandler lobHandler = LOBHandlerFactory.getInstance().getLOBHandler();
			return lobHandler.createClob(conn, ((CLOBStringType) param).getValue());
			// BLOBByteArrayType
		} else if (typeClass.equals(BLOBByteArrayType.class)) {
			LOBHandler lobHandler = LOBHandlerFactory.getInstance().getLOBHandler();
			return lobHandler.createBlob(conn, ((BLOBByteArrayType) param).getValue());
			// BLOBFileType
		} else if (typeClass.equals(BLOBFileType.class)) {
			LOBHandler lobHandler = LOBHandlerFactory.getInstance().getLOBHandler();
			return lobHandler.createBlob(conn, FileUtils.getBytesFromFile(((BLOBFileType) param).getValue()));
			// Not
		} else {
			return param;
		}
	}

}
