/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.query.impl;

import java.util.HashMap;
import java.util.Map;

import org.jdesigner.platform.db.processor.NamedQueryProcessor;
import org.jdesigner.platform.db.processor.impl.NamedQueryProcessorImpl;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.session.Session;

/**
 * <B>Named Query</B>
 * 
 * @author leesangboo
 * 
 */
public class NamedQueryImpl extends SessionQuery implements NamedQuery {

	/**
	 * SQL 파일의 경로
	 */
	private String path; //

	/**
	 * 쿼리 파라메터
	 */
	private Map parameters; //

	/**
	 * Named Query 생성자
	 * 
	 * @param path
	 *            - SQL XML 파일의 경로
	 */
	public NamedQueryImpl(Session session, String path) {
		super.setSession(session);
		this.path = path;
	}

	/**
	 * Named Query 생성자
	 * 
	 * @param path
	 *            - SQL XML 파일의 경로
	 * @param parameters
	 *            - 쿼리 파라메터
	 */
	public NamedQueryImpl(Session session, String path, Map parameters) {
		super.setSession(session);
		this.path = path;
		this.parameters = parameters;
	}

	/**
	 * Query 실행을 위한 프로세서를 반환한다.
	 * 
	 * @return
	 */
	public NamedQueryProcessor execute() {
		return new NamedQueryProcessorImpl(this);
	}

	public Map getParameters() {
		return parameters;
	}

	public void setParameters(Map parameters) {
		this.parameters = parameters;
	}

	public String getPath() {
		return path;
	}

	public void setPath(String path) {
		this.path = path;
	}

	public void addParameter(String key, Object value) {
		if (parameters == null) {
			parameters = new HashMap();
		}
		parameters.put(key, value);
	}

	public void removeParameter(String key) {
		if (parameters != null) {
			parameters.remove(key);
		}
	}

}
