/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.sequence;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

import org.jdesigner.platform.db.connection.ConnectionManager;
import org.jdesigner.platform.db.connection.ConnectionUtils;
import org.jdesigner.platform.db.processor.impl.QueryProcessingException;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * 
 * OracleSequence
 * 
 * @author SangBoo Lee
 * @since 1.0
 * 
 */
public class OracleSequence implements Sequence {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.sequence.Sequence#getNextValue(java.lang.String )
	 */
	public long getNextValue(String sequenceName) throws DatabaseException {

		long nextValue = 0;
		ConnectionManager manager = new ConnectionManager();
		Connection conn = null;
		PreparedStatement pstmt = null;
		ResultSet rs = null;

		try {

			conn = manager.getConnection();
			pstmt = conn.prepareStatement("SELECT " + sequenceName + ".NEXTVAL FROM DUAL");
			rs = pstmt.executeQuery();
			if (rs.next()) {
				nextValue = rs.getBigDecimal(1).longValue();
			} else {
				throw new QueryProcessingException("No result sequence next value.");
			}

		} catch (Exception ex) {
			throw new QueryProcessingException("Sequence getting failed : " + ex.getMessage());
		} finally {
			ConnectionUtils.closeResultSet(rs);
			ConnectionUtils.closeStatement(pstmt);
			ConnectionUtils.closeConnection(conn);
		}

		return nextValue;
	}

}
