/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.table.sql;

import org.jdesigner.platform.db.processor.TableQueryProcessor;
import org.jdesigner.platform.db.table.sql.generator.CountAllSQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.CountByCustomKeySQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.CountByPrimaryKeySQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.DeleteSQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.FindAllSQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.FindByCustomKeySQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.FindByPrimaryKeySQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.InsertSQLGenerator;
import org.jdesigner.platform.db.table.sql.generator.UpdateSQLGenerator;

/**
 * SQLGeneratorFactory
 * 
 * @author leesangboo
 * 
 */
public class SQLGeneratorFactory {

	/**
	 * SQLGenerator를 반환한다.
	 * 
	 * @param mode
	 *            - 쿼리 모드
	 * @return
	 */
	public static SQLGenerator getSQLGenerator(String mode) {
		if (mode == null || mode.equals("")) {
			throw new SQLGeneratorException("Query mode is null, please setting Query in mode.");
		}
		if (mode.equals(TableQueryProcessor.SELECT_ALL)) {
			return new FindAllSQLGenerator();
		} else if (mode.equals(TableQueryProcessor.COUNT_ALL)) {
			return new CountAllSQLGenerator();
		} else if (mode.equals(TableQueryProcessor.SELECT_BY_PRIMARY_KEY)) {
			return new FindByPrimaryKeySQLGenerator();
		} else if (mode.equals(TableQueryProcessor.COUNT_BY_PRIMARY_KEY)) {
			return new CountByPrimaryKeySQLGenerator();
		} else if (mode.equals(TableQueryProcessor.SELECT_BY_CUSTOM_KEY)) {
			return new FindByCustomKeySQLGenerator();
		} else if (mode.equals(TableQueryProcessor.COUNT_BY_CUSTOM_KEY)) {
			return new CountByCustomKeySQLGenerator();
		} else if (mode.equals(TableQueryProcessor.INSERT)) {
			return new InsertSQLGenerator();
		} else if (mode.equals(TableQueryProcessor.UPDATE)) {
			return new UpdateSQLGenerator();
		} else if (mode.equals(TableQueryProcessor.DELETE)) {
			return new DeleteSQLGenerator();
		} else {
			throw new SQLGeneratorException("Not support this table query mode : " + mode);
		}

	}

}
