/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.transaction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * TransactionManager
 * 
 * @author leesangboo
 * 
 */
public class TransactionManager {

	protected static Log log = LogFactory.getLog(TransactionManager.class);

	public void start(Transaction transaction) throws TransactionException {
		if (transaction.isActive()) {
			throw new TransactionException("Already started transaction.");
		} else {
			transaction.start();
			log.info("Transaction[" + transaction.getClass().getName() + "] started.");
		}
	}

	public void commit(Transaction transaction) throws TransactionException {
		if (!transaction.isActive()) {
			throw new TransactionException("Transaction is inactive.");
		} else {
			log.info("Transaction[" + transaction.getClass().getName() + "] commited.");
			transaction.commit();
		}
	}

	public void end(Transaction transaction) {
		if (!transaction.isActive()) {
			if (!transaction.isCommited()) {
				transaction.rollback();
				log.info("Transaction[" + transaction.getClass().getName() + "] rolledback, Because throws exceptions.");
			} else {
				log.info("Transaction has been completed successfully.");
			}
		}

	}

}
