/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.transaction;

import javax.transaction.UserTransaction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.jndi.JTAServiceLocator;

/**
 * JTA 트랜잭션 관리자
 * 
 * @author leesangboo
 * 
 */
public class JTATransactionManager {

	private static final Log log = LogFactory.getLog(JTATransactionManager.class);

	/**
	 * 유저 트랜젝션 시작한다.
	 * 
	 * @return
	 * @throws Exception
	 */
	public UserTransaction begin(String jndiName) throws JTATransactionException {

		UserTransaction userTransaction = null;

		try {

			JTAServiceLocator jtaSerLoc = JTAServiceLocator.getInstance();
			userTransaction = jtaSerLoc.getUserTransaction(jndiName);

			if (userTransaction == null) {
				throw new JTATransactionException("Error create JTA UserTransaction : UserTransaction is NULL");
			}

			userTransaction.begin();

			log.debug("JTA transaction started.");

			return userTransaction;

		} catch (Exception e) {
			log.error(e);
			throw new JTATransactionException("Error create JTA UserTransaction : " + e.getMessage(), e);
		}

	}

	/**
	 * 트랜잭션을 커밋한다.
	 * 
	 * @param userTransaction
	 * @throws Exception
	 */
	public void commit(UserTransaction userTransaction) throws JTATransactionException {
		try {
			userTransaction.commit();
			log.debug("JTA transaction commited.");
		} catch (Exception e) {
			String msg = "JTA transaction manager commit error : " + e.getMessage();
			log.error(msg, e);
			throw new JTATransactionException(msg, e);
		}
	}

	/**
	 * 트랜잭션을 롤백한다.
	 * 
	 * @param userTransaction
	 * @throws Exception
	 */
	public void rollback(UserTransaction userTransaction) {
		try {
			userTransaction.rollback();
			log.debug("JTA transaction rollbacked.");
		} catch (Exception e) {
			String msg = "JTA transaction manager rollback error : " + e.getMessage();
			log.error(msg, e);
			throw new JTATransactionException(msg, e);
		}
	}

}
