package org.jdesigner.platform.util;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.DataMap;

/**
 * <B>Map Utils</B>
 * 
 * @author leesangboo
 * 
 */
public class MapUtils extends org.apache.commons.collections.MapUtils {

	private static final Log log = LogFactory.getLog(MapUtils.class);

	/**
	 * Map 속에 Key 값이 있는지 여부를 반환한다.
	 * 
	 * @param map
	 * @param key
	 * @return
	 */
	public static boolean isEmptyValue(Map map, String key) {
		return (map.containsKey(key) && map.get(key) != null && !(map.get(key)).toString().equals(""));
	}

	/**
	 * 맵속의 데이터를 프린트한다.
	 */
	public static void print(Map map) {
		Object[] keys = map.keySet().toArray();
		for (int i = 0; i < keys.length; i++) {
			if (map.containsKey(keys[i])) {
				if (map.get(keys[i]).getClass().isArray() && ((Object[]) map.get(keys[i])).length > 1) {
					int valueLength = ((Object[]) map.get(keys[i])).length;
					Object[] values = ((Object[]) map.get(keys[i]));
					for (int x = 0; x < valueLength; x++) {
						log.info(" [" + keys[i] + "][" + x + "] -> " + values[x] + "");
					}
				} else {
					Object value = (map.get(keys[i]));
					log.info(" [" + keys[i] + "] -> " + value + "");
				}
			}
		}
	}

	/**
	 * Request parameter map to string query paramter
	 * 
	 * @param map
	 * @return
	 */
	public static String parameterToString(Map map) {
		StringBuffer buffer = new StringBuffer();
		Object[] keys = map.keySet().toArray();
		for (int i = 0; i < keys.length; i++) {
			if (map.get(keys[i]).getClass().isArray() && ((Object[]) map.get(keys[i])).length > 1) {
				int valueLength = ((Object[]) map.get(keys[i])).length;
				Object[] values = ((Object[]) map.get(keys[i]));
				for (int x = 0; x < valueLength; x++) {
					buffer.append("&" + keys[i] + "[" + x + "]=" + values[x] + "");
				}
			} else {
				Object value = ((Object[]) map.get(keys[i]))[0];
				buffer.append("&" + keys[i] + "=" + value + "");
			}

		}
		return buffer.toString();
	}

	/**
	 * DataMap List를 String(선택한 키의 값) List로 변환하여 반환한다.
	 * 
	 * @param sourceList
	 * @return
	 */
	public static List dataMapListToStringList(List sourceList, String key) {
		List targetList = new ArrayList();
		for (int i = 0; sourceList != null && i < sourceList.size(); i++) {
			DataMap data = (DataMap) sourceList.get(i);
			targetList.add(data.getString(key)); //
		}
		return targetList;
	}

	/**
	 * 맵의 키 배열을 반환한다.
	 * 
	 * @param map
	 * @return
	 */
	public static String[] getKeyArray(Map map) {
		if (map == null || map.isEmpty()) {
			return null;
		}
		Object[] keys = map.keySet().toArray();
		String[] newKeys = new String[keys.length];
		for (int i = 0; i < keys.length; i++) {
			newKeys[i] = keys[i].toString();
		}
		return newKeys;
	}

}
