/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMessages;

import org.jdesigner.platform.web.httpmap.ApplicationMap;
import org.jdesigner.platform.web.httpmap.CookieMap;
import org.jdesigner.platform.web.httpmap.ParameterMap;
import org.jdesigner.platform.web.httpmap.RequestMap;
import org.jdesigner.platform.web.httpmap.SessionMap;

/**
 * <B>ActionBeanContext</B>
 * 
 * The ActionBeanContext class gives simplified, thread-safe access to <p/> the request and response, as well as form parameters, request <p/>
 * attributes, session attributes, application attributes. Much <p/> of this can be accopmplished without using the Struts or even <p/> the Servlet
 * API, therefore isolating your application from <p/> presentation framework details. <p/>
 * 
 */
public class ActionBeanContext {

	private static final ThreadLocal localContext = new ThreadLocal();

	//
	private HttpServletRequest request;

	private HttpServletResponse response;

	//
	private Map cookieMap;

	private Map parameterMap;

	private Map requestMap;

	private Map sessionMap;

	private Map applicationMap;

	//
	private ActionEvent event;

	private ActionMessages messages;

	private ActionErrors errors;

	public ActionBeanContext() {
		cookieMap = new HashMap();
		parameterMap = new HashMap();
		requestMap = new HashMap();
		sessionMap = new HashMap();
		applicationMap = new HashMap();
	}

	public static void initCurrentContext(HttpServletRequest request, HttpServletResponse response) {

		ActionBeanContext ctx = getActionBeanContext();

		ctx.request = request;
		ctx.response = response;

		ctx.cookieMap = null;
		ctx.parameterMap = null;
		ctx.requestMap = null;
		ctx.sessionMap = null;
		ctx.applicationMap = null;

		ctx.event = null;
		ctx.messages = null;
		ctx.errors = null;
	}

	public Map getCookieMap() {
		if (cookieMap == null) {
			cookieMap = new CookieMap(request);
		}
		return cookieMap;
	}

	public Map getParameterMap() {
		if (parameterMap == null) {
			parameterMap = new ParameterMap(request);
		}
		return parameterMap;
	}

	public Map getRequestMap() {
		if (requestMap == null) {
			requestMap = new RequestMap(request);
		}
		return requestMap;
	}

	public Map getSessionMap() {
		if (sessionMap == null) {
			sessionMap = new SessionMap(request);
		}
		return sessionMap;
	}

	public Map getApplicationMap() {
		if (applicationMap == null) {
			applicationMap = new ApplicationMap(request);
		}
		return applicationMap;
	}

	public HttpServletRequest getRequest() {
		return request;
	}

	public HttpServletResponse getResponse() {
		return response;
	}

	public ActionEvent getActionEvent() {
		if (event == null) {
			event = new ActionEvent(request);
		}
		return event;
	}

	public ActionMessages getActionMessages() {
		if (messages == null) {
			messages = new ActionMessages();
		}
		return messages;
	}

	public ActionErrors getActionErrors() {
		if (errors == null) {
			errors = new ActionErrors();
		}
		return errors;
	}

	public static ActionBeanContext getActionBeanContext() {
		ActionBeanContext ctx = (ActionBeanContext) localContext.get();
		if (ctx == null) {
			ctx = new ActionBeanContext();
			localContext.set(ctx);
		}
		return ctx;
	}

}
