/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.beanutils.BeanUtils;

import org.jdesigner.platform.util.ReflectionUtils;
import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.InputsList;
import org.jdesigner.platform.web.table.Table;

/**
 * ActionObjectBinder
 * 
 * @author leesangboo
 * 
 */
public class DataObjectBinder {

	/**
	 * BeanAction에 Form Object를 바인딩한다.
	 * 
	 * @param request
	 * @param bean
	 */
	public static void bind(HttpServletRequest request, Object bean) throws BeanActionException {

		// Form 객체에 배열을 포함한 재 바인딩
		try {
			Field[] fields = bean.getClass().getDeclaredFields();
			for (int i = 0; fields != null && i < fields.length; i++) {
				final Field field = fields[i];
				final String fieldName = field.getName();
				if (field.getType() == Form.class) {
					Form bindedForm = new Form();
					Enumeration paramNames = request.getParameterNames();
					while (paramNames.hasMoreElements()) {
						String paramName = (String) paramNames.nextElement();
						if (paramName.startsWith(fieldName + ".")) {
							String[] value = request.getParameterValues(paramName);
							if (value != null && value.length > 1) {
								bindedForm.put(paramName.replace(fieldName + ".", ""), value);
							} else {
								bindedForm.put(paramName.replace(fieldName + ".", ""), value[0]);
							}
							// log.debug("bind param to form : name = " +
							// paramName);
						}
					}
					;
					BeanUtils.setProperty(bean, fieldName, bindedForm);
				}
			}
		} catch (Exception ex) {
			throw new BeanActionException("Error prameter to bean [Form] binding.", ex);
		}

		// InputsList 바인딩
		try {
			Field[] fields = bean.getClass().getDeclaredFields();
			for (int i = 0; fields != null && i < fields.length; i++) {
				final Field field = fields[i];
				final String fieldName = field.getName();
				// log.info("fieldName=" + fieldName);
				if (field.getType() == InputsList.class) {
					String methodName = "get" + fieldName.substring(0, 1).toUpperCase() + fieldName.substring(1);
					Method method = bean.getClass().getMethod(methodName, null);

					InputsList bindedInputsList = (InputsList) ReflectionUtils.invokeMethod(method, bean);
					String[] names = bindedInputsList.getNames();
					if (names == null || names.length < 1) {
						Enumeration paramNames = request.getParameterNames();
						int colIndex = 0;
						List colList = new ArrayList();
						while (paramNames.hasMoreElements()) {
							String paramName = (String) paramNames.nextElement();
							if (paramName.startsWith(fieldName + ".")) {
								String bindFieldName = paramName.replace((fieldName + "."), "");
								colList.add(bindFieldName);
								colIndex++;
							}
						}
						if (colIndex == 0) {
							names = new String[0];
							bindedInputsList.setNames(names);
						} else {
							names = new String[colIndex];
							for (int ri = 0; ri < colList.size(); ri++) {
								names[ri] = (String) colList.get(ri);
							}
							bindedInputsList.setNames(names);
						}
					}
					// log.info("names=" + names);
					if (names != null && names.length > 0) {
						// 첫번째 파라메터 기준의 길이
						String[] firstValues = request.getParameterValues(fieldName + "." + names[0]);
						// log.info("firstValues.length=" + firstValues.length);
						for (int row = 0; firstValues != null && row < firstValues.length; row++) {
							Form inputsForm = new Form();
							// log.info("row=" + row);
							for (int column = 0; column < names.length; column++) {
								String[] values = request.getParameterValues(fieldName + "." + names[column]);
								// log.info("values=" + values);
								if (values != null) {
									inputsForm.put(names[column], values[row]);
								} else {
									inputsForm.put(names[column], null);
								}
								// log.info("names[column]=" + names[column]);
								// log.info("values[row]=" + values[row]);
							}
							bindedInputsList.add(inputsForm);
						}
						BeanUtils.setProperty(bean, fieldName, bindedInputsList);
					}
					;

				}
			}
		} catch (Exception ex) {
			throw new BeanActionException("Error prameter to bean [InputsList] binding.", ex);
		}

		// Table 바인딩
		try {
			Field[] fields = bean.getClass().getDeclaredFields();
			for (int i = 0; fields != null && i < fields.length; i++) {
				final Field field = fields[i];
				final String fieldName = field.getName();
				if (field.getType() == Table.class) {
					String methodName = "get" + fieldName.substring(0, 1).toUpperCase() + fieldName.substring(1);
					Method method = bean.getClass().getMethod(methodName, null);

					Table bindedTable = (Table) ReflectionUtils.invokeMethod(method, bean);
					String[] names = bindedTable.getNames();
					if (names == null || names.length < 1) {
						Enumeration paramNames = request.getParameterNames();
						int colIndex = 0;
						List colList = new ArrayList();
						while (paramNames.hasMoreElements()) {
							String paramName = (String) paramNames.nextElement();
							if (paramName.startsWith(fieldName + ".")) {
								String bindFieldName = paramName.replace((fieldName + "."), "");
								colList.add(bindFieldName);
								colIndex++;
							}
						}
						if (colIndex == 0) {
							names = new String[0];
							bindedTable.setNames(names);
						} else {
							names = new String[colIndex];
							for (int ri = 0; ri < colList.size(); ri++) {
								names[ri] = (String) colList.get(ri);
							}
							bindedTable.setNames(names);
						}
					}
					// log.info("names=" + names);
					if (names != null && names.length > 0) {
						// 첫번째 파라메터 기준의 길이
						String[] firstValues = request.getParameterValues(fieldName + "." + names[0]);
						// log.info("firstValues.length=" + firstValues.length);
						for (int row = 0; firstValues != null && row < firstValues.length; row++) {
							Form inputsForm = new Form();
							// log.info("row=" + row);
							for (int column = 0; column < names.length; column++) {
								String[] values = request.getParameterValues(fieldName + "." + names[column]);
								// log.info("values=" + values);
								if (values != null) {
									inputsForm.put(names[column], values[row]);
								} else {
									inputsForm.put(names[column], null);
								}
								// log.info("names[column]=" + names[column]);
								// log.info("values[row]=" + values[row]);
							}
							bindedTable.add(inputsForm);
						}
						BeanUtils.setProperty(bean, fieldName, bindedTable);
					}
					;

				}
			}
		} catch (Exception ex) {
			throw new BeanActionException("Error prameter to bean [Table] binding.", ex);
		}
	};

}
