/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.io.File;
import java.util.ArrayList;

import org.jdesigner.platform.util.PatternMatchUtils;
import org.jdesigner.platform.util.StringUtils;

/**
 * XMLFileReader
 * 
 * @author leesangboo
 * 
 */
public class XMLFileReader {

	/**
	 * <P> 지정된 루트 폴더를 기준으로 설정된 파일 확장자를 갖는 모든 파일 리스트를 가져오는 메소드 </P>
	 * 
	 * @param appPath
	 * @param basePath
	 * @param fileExtFilter
	 * @return
	 * @throws Exception
	 */
	public static String[] getAllFilePathArray(String appPath, String basePath, String fileExtFilter) throws Exception {
		String fullPath = StringUtils.cleanPath(appPath + basePath);
		File rootFolder = new File(fullPath);
		if ((rootFolder == null) || !rootFolder.exists()) {
			throw new Exception("Not exist strtus base configuration path : [" + fullPath + "]");
		}

		ArrayList subFileList = new ArrayList();

		readDirectoryFileList(appPath, rootFolder, subFileList, fileExtFilter);

		return (String[]) subFileList.toArray(new String[subFileList.size()]);
	}

	/**
	 * readDirectoryFileList
	 * 
	 * @param appPath
	 * @param pivotFolder
	 * @param subFileList
	 * @param fileExtFilter
	 * @throws Exception
	 */
	private static void readDirectoryFileList(String appPath, File pivotFolder, ArrayList subFileList, String fileExtFilter) throws Exception {
		if (pivotFolder.isDirectory()) {
			File[] list = pivotFolder.listFiles();

			for (int inx = 0; inx < list.length; inx++) {
				File subFile = list[inx];

				if (subFile.isDirectory()) {
					readDirectoryFileList(appPath, subFile, subFileList, fileExtFilter);
				} else {
					if (isAvailableFile(subFile, fileExtFilter)) {
						String subFilePath = getPath(appPath, subFile);
						subFileList.add(subFilePath);
					}
				}
			}
		} else {
			throw new Exception("If the folder does not exist or the specified file has been set : [" + pivotFolder.getAbsolutePath() + "]");
		}
	}

	/**
	 * isAvailableFile
	 * 
	 * @param subFile
	 * @param fileExtFilter
	 * @return
	 */
	private static boolean isAvailableFile(File subFile, String fileExtFilter) {
		String lowerSubFileName = subFile.getName().trim().toLowerCase();
		String lowerFileExtFilter = fileExtFilter.trim().toLowerCase();
		return PatternMatchUtils.simpleMatch(lowerFileExtFilter, lowerSubFileName);

	}

	/**
	 * getPath
	 * 
	 * @param appPath
	 * @param subFile
	 * @return
	 * @throws Exception
	 */
	private static String getPath(String appPath, File subFile) throws Exception {
		try {
			String cleanAppPath = StringUtils.cleanPath(appPath);
			String cleanCanonicalPath = StringUtils.cleanPath(subFile.getCanonicalPath());
			return StringUtils.cleanPath("/" + cleanCanonicalPath.replaceAll(cleanAppPath, ""));
		} catch (Exception e) {
			throw new Exception("Does not read the file : [" + subFile.getAbsolutePath() + "]");
		}
	}
}
