/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.filter;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.core.threadlocal.ThreadLocalProperties;

/**
 * ThreadLocalFilter
 * 
 * @author leesangboo
 * 
 */
public class ThreadLocalFilter implements Filter {

	private static Log log = LogFactory.getLog(ThreadLocalFilter.class);

	private static final String FILTER_JSESSION_ID_KEY = "_FILTER_JSESSION_ID_KEY";

	public ThreadLocalFilter() {
		//
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#init(javax.servlet.FilterConfig)
	 */
	public void init(FilterConfig filterConfig) throws ServletException {

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)
	 */
	public void doFilter(ServletRequest srequest, ServletResponse response, FilterChain chain) throws java.io.IOException, ServletException {

		try {

			HttpServletRequest request = (HttpServletRequest) srequest;

			//
			ThreadLocalProperties.put(FILTER_JSESSION_ID_KEY, request.getSession().getId());
			log.debug("ThreadLocalFilter save [jsessionid] in ThreadLocalProperties.");

			//
			chain.doFilter(request, response);

		} catch (Exception ex) {
			log.error("ThreadLocalFilter error : " + ex.getMessage(), ex);
			throw new ServletException(ex);
		} finally {
			ThreadLocalProperties.remove(FILTER_JSESSION_ID_KEY);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#destroy()
	 */
	public void destroy() {
		/*
		 * called before the Filter instance is removed from service by the web container
		 */
	}
}
