/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.json;

import java.lang.reflect.Method;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.sf.json.JSONObject;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.util.ReflectionUtils;
import org.jdesigner.platform.web.ActionBean;

//import org.jdesigner.platform.web.form.Form;

/**
 * JSONResponseWriter
 * 
 * @author leesangboo
 * 
 */
public class JSONResponseWriter {

	private static final Log log = LogFactory.getLog(JSONResponseWriter.class);

	private boolean debug = false;

	private HttpServletRequest request;

	private HttpServletResponse response;

	/**
	 * JSONResponseWriter
	 * 
	 * @param request
	 * @param response
	 */
	public JSONResponseWriter(HttpServletRequest request, HttpServletResponse response, boolean debug) {
		this.debug = debug;
		this.request = request;
		this.response = response;
	}

	/**
	 * Print json string in jsp
	 * 
	 * @throws Exception
	 */
	public void write() throws Exception {
		try {
			String json = getString();
			try {
				// response.setContentType("text/x-json");
				response.getOutputStream().print(json);
			} catch (java.lang.IllegalStateException ie) {
				response.getWriter().print(json);
			}
		} catch (Exception ex) {
			log.error("Grid JSON result writing error : " + ex.getMessage(), ex);
			throw ex;
		}
	}

	/**
	 * json getString
	 * 
	 * @return
	 * @throws Exception
	 */
	public String getString() throws Exception {
		StringBuffer buffer = new StringBuffer();
		Enumeration enumeration = request.getAttributeNames();
		Map map = new HashMap();
		if (enumeration != null) {
			while (enumeration.hasMoreElements()) {
				String key = enumeration.nextElement().toString();
				Object obj = request.getAttribute(key);
				if (obj instanceof ActionBean) {
					Method[] methods = obj.getClass().getMethods();
					for (int i = 0; methods != null && i < methods.length; i++) {
						// Form
						/*
						 * if( methods[i].getReturnType() == Form.class){ String methodName = methods[i].getName(); String property =
						 * methodName.replace("get", "").substring(0,1).toLowerCase() + methodName.replace("get", "").substring(1); Form form = (Form)
						 * ReflectionUtils.invokeMethod(methods[i], obj); map.put(property, form); };
						 */
						// JSON
						if (methods[i].getReturnType() == JSONResult.class) {
							String methodName = methods[i].getName();
							String property = methodName.replace("get", "").substring(0, 1).toLowerCase() + methodName.replace("get", "").substring(1);
							JSONResult json = (JSONResult) ReflectionUtils.invokeMethod(methods[i], obj);
							map.put(property, json);
						}
						;
					}
				}
			}
		}
		//
		JSONObject jsonObject = JSONObject.fromObject(map);
		buffer.append(jsonObject);

		if (debug) {
			log.info("JSON Result = " + buffer.toString());
		}

		return buffer.toString();
	}

}
