/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.multipart;

import java.io.File;
import java.io.FileOutputStream;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.upload.FormFile;

import org.jdesigner.platform.context.ApplicationConfig;
import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.util.StringUtils;

/**
 * FormFileUploader
 * @author leesangboo
 * 
 */
public class FormFileUploader {

	private static final Log log = LogFactory.getLog(FormFileUploader.class);

	private static final String REPOSITORY_DIR = "platform.web.multipart.repository";

	public static String saveFormFile(FormFile formFile) throws Exception {
		return saveFormFile(formFile, getRepositoryDir(), new BaseFileRenameHandler());
	}

	public static String saveFormFile(FormFile formFile, String dir) throws Exception {
		return saveFormFile(formFile, dir, new BaseFileRenameHandler());
	}

	public static String saveFormFile(FormFile formFile, String dir, FileRenameHandler handler) throws Exception {
		String savedFilePath = null;
		FileOutputStream out = null;

		String fileName = null;
		byte[] fileData = null;

		try {
			fileName = formFile.getFileName();
			fileData = formFile.getFileData();

			File saveDir = new File(dir);
			if (!saveDir.isDirectory()) {
				saveDir.mkdir();
			}

			File writeFile = handler.renameFile(dir, fileName);
			out = new FileOutputStream(writeFile);
			out.write(fileData);
			out.flush();
			out.close();

			//
			savedFilePath = StringUtils.cleanPath(dir + writeFile.getName());

			//
			log.info("Form file saved : savedFilePath=[" + savedFilePath + "]");

		} catch (Exception ex) {

			log.error("Form file save failed : " + ex.getMessage(), ex);
			out.close();
		} finally {
			out.close();
		}

		return savedFilePath;
	}

	private static ApplicationConfig getApplicationConfig() {
		ApplicationContextFactory appFactory = ApplicationContextFactory.getInstance();
		ApplicationConfig appConfig = appFactory.getApplicationContext().getApplicationConfig();
		return appConfig;
	}

	private static String getRepositoryDir() {
		return getApplicationConfig().getProperty(REPOSITORY_DIR);
	}

}
