/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.html;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspException;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;

import org.jdesigner.platform.util.ReflectionUtils;
import org.jdesigner.platform.web.BaseBean;
import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormAction;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.tag.TagConstants;

/**
 * FormTag
 * 
 * @author leesangboo
 * 
 */
public class FormTag extends org.apache.struts.taglib.html.FormTag implements TagConstants {

	private static final String INSERT_ACTION = FormAction.INSERT;

	private static final String UPDATE_ACTION = FormAction.UPDATE;

	private String mapping = "";

	private String path = "";

	private String insertAction = "";

	private String updateAction = "";

	private String deleteAction = "";

	private String mode = "";

	private boolean validate = false;

	private String property = "";

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public String renderFormStartElement() throws JspException {

		StringBuffer results = new StringBuffer();

		if (!StringUtils.isEmpty(property)) {
			setStyleId(property); //
		}

		//검증 스크립트 작성 여부
		if (validate) {
			results.append(SCRIPT_TAG_START);
			results.append("var " + styleId + "_validation;").append("\n");
			results.append("window.addEvent('domready', function(){	").append("\n");
			results.append("	  " + styleId + "_validation = form.validation('" + this.styleId + "');").append("\n");
			results.append("});").append("\n");
			results.append(SCRIPT_TAG_END);
		}

		//폼 전송 준비
		//super.setOnsubmit("form.prepare(this);" + getOnsubmit());

		//
		HttpServletRequest request = (HttpServletRequest) super.pageContext.getRequest();
		String strutsUrl = (String) request.getAttribute("org.apache.struts.globals.ORIGINAL_URI_KEY");
		if (strutsUrl != null) {
			strutsUrl = strutsUrl.trim();
		}

		//1. 맵핑을 통한 액션 URL 정의
		if (!StringUtils.isEmpty(mapping)) {
			if (strutsUrl.endsWith("add.do") || strutsUrl.endsWith("copy.do")) {
				action = java.text.MessageFormat.format(mapping, new Object[] { INSERT_ACTION });
			} else if (strutsUrl.endsWith("edit.do")) {
				action = java.text.MessageFormat.format(mapping, new Object[] { UPDATE_ACTION });
			} else {
				action = mapping;
			}
		}

		//2. Mode에 의한 액션 URL 정의
		if (!StringUtils.isEmpty(path) && !StringUtils.isEmpty(mode)) {
			if (mode.equals(FormMode.INSERT)) {
				if (StringUtils.isEmpty(insertAction)) {
					action = path + INSERT_ACTION;
				} else {
					action = path + insertAction;
				}
			} else if (mode.equals(FormMode.UPDATE)) {
				if (StringUtils.isEmpty(updateAction)) {
					action = path + UPDATE_ACTION;
				} else {
					action = path + updateAction;
				}
			} else {
				throw new JspException("Unsupport this form mode : mode=[" + mode + "]");
			}
		}

		//3. FORM 모드 분석을 통한 액션 URL 정의
		String actionURL = null;
		if (!StringUtils.isEmpty(property) && !StringUtils.isEmpty(path)) {
			try {
				BaseBean bean = (BaseBean) request.getAttribute(super.beanName);
				Field[] fields = bean.getClass().getDeclaredFields();
				for (int i = 0; fields != null && i < fields.length; i++) {
					final Field field = fields[i];
					final String fieldName = field.getName();
					if (fieldName.equals(property) && field.getType() == Form.class) {
						String methodName = "get" + fieldName.substring(0, 1).toUpperCase() + fieldName.substring(1);
						Method method = bean.getClass().getMethod(methodName, null);
						Form form = (Form) ReflectionUtils.invokeMethod(method, bean);
						mode = BeanUtils.getProperty(form, "mode");
						actionURL = BeanUtils.getProperty(form, "url");
					}
				}
			} catch (Exception ex) {
				throw new JspException("Error find mode from Form object.", ex);
			}
			//
			//System.out.println("Form mode=" + mode);
			if (actionURL == null) {
				if (!mode.equals(FormMode.NONE)) {
					if (mode.equals(FormMode.INSERT)) {
						if (StringUtils.isEmpty(insertAction)) {
							action = path + INSERT_ACTION;
						} else {
							action = path + insertAction;
						}
					} else if (mode.equals(FormMode.UPDATE)) {
						if (StringUtils.isEmpty(updateAction)) {
							action = path + UPDATE_ACTION;
						} else {
							action = path + updateAction;
						}
					}
				}
			} else {
				action = actionURL;
			}
		}

		//
		if (action == null || action.equals("") || action.equals("/")) {
			action = null;
		}

		//
		results.append("<form");

		// render attributes
		renderName(results);

		renderAttribute(results, "method", (getMethod() == null) ? "post" : getMethod().toLowerCase());

		renderAction(results);

		renderAttribute(results, "accept-charset", getAcceptCharset());
		renderAttribute(results, "class", getStyleClass());
		renderAttribute(results, "dir", getDir());
		renderAttribute(results, "enctype", getEnctype());
		renderAttribute(results, "lang", getLang());
		renderAttribute(results, "onreset", getOnreset());
		renderAttribute(results, "onsubmit", getOnsubmit());
		renderAttribute(results, "style", getStyle());
		renderAttribute(results, "target", getTarget());
		// if (!isXhtml()) {
		// renderAttribute(results, "autocomplete", getAutocomplete());
		// }

		// Hook for additional attributes
		renderOtherAttributes(results);

		results.append(">");

		return results.toString();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.apache.struts.taglib.html.FormTag#renderName(java.lang.StringBuffer)
	 */
	protected void renderName(StringBuffer results) throws JspException {
		renderAttribute(results, "name", beanName);
		renderAttribute(results, "id", getStyleId());
	}

	public boolean isValidate() {
		return validate;
	}

	public void setValidate(boolean validate) {
		this.validate = validate;
	}

	public String getMapping() {
		return mapping;
	}

	public void setMapping(String mapping) {
		this.mapping = mapping;
	}

	/**
	 * @return the path
	 */
	public String getPath() {
		return path;
	}

	/**
	 * @param path
	 *            the path to set
	 */
	public void setPath(String path) {
		this.path = path;
	}

	/**
	 * @return the mode
	 */
	public String getMode() {
		return mode;
	}

	/**
	 * @param mode
	 *            the mode to set
	 */
	public void setMode(String mode) {
		this.mode = mode;
	}

	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getInsertAction() {
		return insertAction;
	}

	public void setInsertAction(String insertAction) {
		this.insertAction = insertAction;
	}

	public String getUpdateAction() {
		return updateAction;
	}

	public void setUpdateAction(String updateAction) {
		this.updateAction = updateAction;
	}

	public String getDeleteAction() {
		return deleteAction;
	}

	public void setDeleteAction(String deleteAction) {
		this.deleteAction = deleteAction;
	}

}
