/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui;

import org.apache.commons.lang.StringUtils;

import org.jdesigner.platform.web.tag.ui.template.UITemplateModel;

/**
 * 버튼 태그
 * 
 * @author leesangboo
 * 
 */
public class ButtonTag extends BaseUITag {

	private static final long serialVersionUID = 1L;

	private static final String BUTTON_TEMPLATE_PATH = "button.ftl";

	private String type;

	private String icon;

	private String onclick;

	private boolean disabled;

	private String styleClass;

	private String accessKey;

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.tag.ui.BaseUITag#getStartModel()
	 */
	public UITemplateModel getStartModel() throws Exception {
		UITemplateModel model = new UITemplateModel(BUTTON_TEMPLATE_PATH);
		model.put("id", id);
		model.put("type", type);
		// TODO : URL 변경
		if (StringUtils.isNotEmpty(icon) && icon.startsWith("/")) {
			model.put("icon", getRequest().getContextPath() + icon);
		} else {
			model.put("icon", icon);
		}

		model.put("label", label);
		model.put("onclick", onclick);
		model.put("disabled", disabled);
		model.put("styleClass", styleClass);
		model.put("accessKey", accessKey);
		return model;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.tag.ui.BaseUITag#getEndModel()
	 */
	public UITemplateModel getEndModel() throws Exception {
		UITemplateModel model = new UITemplateModel(BUTTON_TEMPLATE_PATH);
		return model;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see oracle.erp.common.web.taglib.BaseUITag#reset()
	 */
	public void reset() {
		type = "";
		icon = "";
		onclick = "";
		accessKey = "";
		disabled = false;
	}

	public boolean isDisabled() {
		return disabled;
	}

	public void setDisabled(boolean disabled) {
		this.disabled = disabled;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getOnclick() {
		return onclick;
	}

	public void setOnclick(String onclick) {
		this.onclick = onclick;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getIcon() {
		return icon;
	}

	public void setIcon(String icon) {
		this.icon = icon;
	}

	public String getStyleClass() {
		return styleClass;
	}

	public void setStyleClass(String styleClass) {
		this.styleClass = styleClass;
	}

	public String getAccessKey() {
		return accessKey;
	}

	public void setAccessKey(String accessKey) {
		this.accessKey = accessKey;
	}

}
