/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui;

import java.util.Locale;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.PageContext;

import org.apache.struts.util.MessageResources;

import org.jdesigner.platform.util.StringUtils;
import org.jdesigner.platform.web.WebUtils;
import org.jdesigner.platform.web.theme.Theme;

/**
 * Tag Helper
 * 
 * @author leesangboo
 * 
 */
abstract public class TagHelper {

	/**
	 * HTML TAG 속성을 렌더링한다.
	 * 
	 * @param key
	 * @param value
	 * @return
	 */
	public String renderAttribute(String key, String value) {
		return key + "=\"" + value + "\" ";
	}

	/**
	 * i18n여부에 따른 메세지를 반환한다.
	 * 
	 * @param request
	 * @param key
	 * @param bundle
	 * @param isI18n
	 * @return
	 */
	public String getMessage(HttpServletRequest request, String key, String bundle, boolean isI18n) {
		if (isI18n) {
			if (StringUtils.isNotEmpty(bundle)) {
				MessageResources messageResources = WebUtils.getResources(request, bundle);
				return messageResources.getMessage(key);
			} else {
				MessageResources messageResources = WebUtils.getResources(request);
				return messageResources.getMessage(key);
			}
		} else {
			return key;
		}
	}

	/**
	 * HttpServletRequest을 반환한다.
	 * 
	 * @return
	 */
	public HttpServletRequest getRequest(PageContext pageContext) {
		return ((HttpServletRequest) pageContext.getRequest());
	}

	/***
	 * HttpServletResponse을 반환한다.
	 * 
	 * @return
	 */
	public HttpServletResponse getResponse(PageContext pageContext) {
		return ((HttpServletResponse) pageContext.getResponse());
	}

	/**
	 * Context Path를 반환한다.
	 * 
	 * @return
	 */
	public String getContextPath(PageContext pageContext) {
		return getRequest(pageContext).getContextPath();
	}

	/**
	 * 사용자의 테마를 반환한다.
	 * 
	 * @return
	 */
	public Theme getUserTheme(PageContext pageContext) {
		return WebUtils.getThemeHandler().getUserTheme(getRequest(pageContext));
	}

	/**
	 * 사용자의 로케일을 반환한다.
	 * 
	 * @return
	 */
	public Locale getUserLocale(PageContext pageContext) {
		return WebUtils.getLocaleHandler().getUserLocale(getRequest(pageContext), getResponse(pageContext));
	}

}
