/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tiles;

import java.io.FileNotFoundException;
import java.util.Map;

import javax.servlet.ServletContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.tiles.DefinitionsFactoryException;
import org.apache.struts.tiles.FactoryNotFoundException;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.util.StringUtils;
import org.jdesigner.platform.web.XMLFileReader;

/**
 * <B>TilesI18nFactorySet</B>
 * 
 * @author leesangboo
 * 
 */
public class I18nFactorySet extends org.apache.struts.tiles.xmlDefinition.I18nFactorySet {

	private static final long serialVersionUID = 1L;

	protected static Log log = LogFactory.getLog(I18nFactorySet.class);

	public I18nFactorySet() {
		super();
	}

	public void initFactory(ServletContext servletContext, Map properties) throws DefinitionsFactoryException {

		// Set some property values
		String value = (String) properties.get(PARSER_VALIDATE_PARAMETER_NAME);
		if (value != null) {
			isValidatingParser = Boolean.valueOf(value).booleanValue();
		}

		value = (String) properties.get(PARSER_DETAILS_PARAMETER_NAME);
		if (value != null) {
			try {
				parserDetailLevel = Integer.valueOf(value).intValue();

			} catch (NumberFormatException ex) {
				log.error("Bad format for parameter '" + PARSER_DETAILS_PARAMETER_NAME + "'. Integer expected.");
			}
		}

		String filename = null;

		log.info("Using global tiles configuration file loading option.");

		ApplicationContextFactory factory = ApplicationContextFactory.getInstance();
		String appPath = factory.getApplicationContext().getAppPath();

		String config = (String) properties.get(DEFINITIONS_CONFIG_PARAMETER_NAME);
		if (config == null || config.split(",").length < 2) {
			throw new DefinitionsFactoryException("Not setting parameter[" + DEFINITIONS_CONFIG_PARAMETER_NAME + "] values : ex)/WEB-INF/config/,*-tiles-defs.xml");
		}
		String configXmlBasePath = config.split(",")[0];
		String configXmlPattern = config.split(",")[1];

		if (StringUtils.isEmpty(configXmlBasePath) || StringUtils.isEmpty(configXmlPattern)) {
			String msg = "Tiles plugin initialization parameters [definitions-config-base-path] or [definitions-config-pattern], please set up.";
			log.error(msg);
			throw new DefinitionsFactoryException(msg);
		}

		String[] pathArray = null;
		try {
			pathArray = XMLFileReader.getAllFilePathArray(appPath, configXmlBasePath, configXmlPattern);
		} catch (Exception e) {
			String msg = "XMLFileReader exception : " + e.getMessage();
			log.error(msg);
			throw new DefinitionsFactoryException(msg);
		}

		if (pathArray != null && pathArray.length > 0) {
			String commaCombinedPath = "";
			for (int i = 0, size = pathArray.length; i < size; i++) {
				commaCombinedPath += "," + pathArray[i];
			}
			filename = commaCombinedPath.substring(1);
			log.info("Loaded tiles configuration files = [" + filename + "]");
		} else {
			String msg = "Not founds tiles configuration files.";
			log.error(msg);
			throw new DefinitionsFactoryException(msg);
		}

		if (filename != null) { // Use provided filename
			try {
				initFactory(servletContext, filename);
				if (log.isDebugEnabled()) {
					log.debug("Factory initialized from file '" + filename + "'.");
				}
			} catch (FileNotFoundException ex) { // A filename is specified,
				// throw appropriate error.
				log.error(ex.getMessage() + " : Can't find file '" + filename + "'");
				throw new FactoryNotFoundException(ex.getMessage() + " : Can't find file '" + filename + "'");
			}

		} else {
			// try each default file names
			throw new DefinitionsFactoryException("Not found tiles defination files.");
		}

		log.info("Initialized tiles i18n factory set.");

	}

}
